--use DiversityReferences

--##################################################################################################
--  ROLES  #########################################################################################
--##################################################################################################

CREATE ROLE [DiversityReferencesAdministrator] AUTHORIZATION [dbo]
GO

CREATE ROLE [DiversityReferencesEditor] AUTHORIZATION [dbo]
GO

CREATE ROLE [DiversityReferencesUser] AUTHORIZATION [dbo]
GO

--##################################################################################################
--  ProjectProxy  ##################################################################################
--##################################################################################################


CREATE TABLE [dbo].[ProjectProxy](
	[ProjectID] [int] NOT NULL,
	[Project] [nvarchar](50) NULL,
 CONSTRAINT [PK_DiversityProjectProxy] PRIMARY KEY CLUSTERED 
(
	[ProjectID] ASC
))

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'ID of the project to which the specimen belongs (Projects are defined in DiversityProjects)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ProjectProxy', @level2type=N'COLUMN',@level2name=N'ProjectID'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The name or title of the project as shown in a user interface  (Projects are defined in DiversityProjects)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ProjectProxy', @level2type=N'COLUMN',@level2name=N'Project'
GO


GRANT SELECT ON [dbo].[ProjectProxy] TO [DiversityReferencesUser]
GRANT INSERT ON [dbo].[ProjectProxy] TO [DiversityReferencesAdministrator]
GRANT UPDATE ON [dbo].[ProjectProxy] TO [DiversityReferencesAdministrator]
GRANT DELETE ON [dbo].[ProjectProxy] TO [DiversityReferencesAdministrator]



--##################################################################################################
--  UserProxy  #####################################################################################
--##################################################################################################


CREATE TABLE [dbo].[UserProxy](
	[LoginName] [nvarchar](50) NOT NULL,
	[CombinedNameCache] [nvarchar](255) NOT NULL,
	[UserURI] [varchar](255) NULL,
 CONSTRAINT [PK_UserProxy] PRIMARY KEY CLUSTERED 
(
	[LoginName] ASC
))
GO


EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A login name which the user uses  for access the DivesityWorkbench, Microsoft domains, etc..' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserProxy', @level2type=N'COLUMN',@level2name=N'LoginName'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_DisplayControl', @value=N'109' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserProxy', @level2type=N'COLUMN',@level2name=N'LoginName'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Format', @value=N'' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserProxy', @level2type=N'COLUMN',@level2name=N'LoginName'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The short name of the user, e.g. P. Smith' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserProxy', @level2type=N'COLUMN',@level2name=N'CombinedNameCache'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'URI of a user in a remote module, e.g. refering to UserInfo.UserID in database DiversityUsers' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserProxy', @level2type=N'COLUMN',@level2name=N'UserURI'
GO


GRANT SELECT ON [dbo].[UserProxy] TO [DiversityReferencesUser]
GRANT INSERT ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]
GRANT UPDATE ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]
GRANT DELETE ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]


--##################################################################################################
--  ProjectUser  ###################################################################################
--##################################################################################################

CREATE TABLE [dbo].[ProjectUser](
	[LoginName] [nvarchar](50) NOT NULL,
	[ProjectID] [int] NOT NULL,
 CONSTRAINT [PK_ProjectUser] PRIMARY KEY CLUSTERED 
(
	[LoginName] ASC,
	[ProjectID] ASC
)) 
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A login name which the user uses  for access the DivesityWorkbench, Microsoft domains, etc..' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ProjectUser', @level2type=N'COLUMN',@level2name=N'LoginName'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'ID of the project to which the specimen belongs (Projects are defined in DiversityProjects)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ProjectUser', @level2type=N'COLUMN',@level2name=N'ProjectID'
GO

ALTER TABLE [dbo].[ProjectUser]  WITH CHECK ADD  CONSTRAINT [FK_DiversityProjectUser_DiversityProjectProxy] FOREIGN KEY([ProjectID])
REFERENCES [dbo].[ProjectProxy] ([ProjectID])
ON UPDATE CASCADE
GO

ALTER TABLE [dbo].[ProjectUser] CHECK CONSTRAINT [FK_DiversityProjectUser_DiversityProjectProxy]
GO

ALTER TABLE [dbo].[ProjectUser]  WITH NOCHECK ADD  CONSTRAINT [FK_ProjectUser_UserProxy] FOREIGN KEY([LoginName])
REFERENCES [dbo].[UserProxy] ([LoginName])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[ProjectUser] CHECK CONSTRAINT [FK_ProjectUser_UserProxy]
GO

GRANT SELECT ON [dbo].[UserProxy] TO [DiversityReferencesUser]
GRANT INSERT ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]
GRANT UPDATE ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]
GRANT DELETE ON [dbo].[UserProxy] TO [DiversityReferencesAdministrator]



--##################################################################################################
--  ReferenceProject  ##############################################################################
--##################################################################################################


CREATE TABLE [dbo].[ReferenceProject](
	[RefID] [int] NOT NULL,
	[ProjectID] [int] NOT NULL,
	[LogCreatedWhen] [datetime] NULL,
	[LogCreatedBy] [nvarchar](50) NULL,
	[LogUpdatedWhen] [datetime] NULL,
	[LogUpdatedBy] [nvarchar](50) NULL,
 CONSTRAINT [PK_ReferenceProject] PRIMARY KEY CLUSTERED 
(
	[RefID] ASC,
	[ProjectID] ASC
))
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Refers to the ID of ReferenceTitle (= Foreign key and part of primary key)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'RefID'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'ID of the project to which the Reference belongs (Projects are defined in DiversityProjects)' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'ProjectID'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The time when this dataset was created' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'LogCreatedWhen'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Who created this dataset' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'LogCreatedBy'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The last time when this dataset was updated' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'LogUpdatedWhen'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Who was the last to update this dataset' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject', @level2type=N'COLUMN',@level2name=N'LogUpdatedBy'
GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The projects within which the Reference were placed' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ReferenceProject'
GO

ALTER TABLE [dbo].[ReferenceProject]  WITH NOCHECK ADD  CONSTRAINT [FK_ReferenceProject_ReferenceTitle] FOREIGN KEY([RefID])
REFERENCES [dbo].ReferenceTitle ([RefID])
ON UPDATE CASCADE
ON DELETE CASCADE
GO

ALTER TABLE [dbo].[ReferenceProject] CHECK CONSTRAINT [FK_ReferenceProject_ReferenceTitle]
GO

ALTER TABLE [dbo].[ReferenceProject]  WITH NOCHECK ADD  CONSTRAINT [FK_ReferenceProject_DiversityProjectProxy] FOREIGN KEY([ProjectID])
REFERENCES [dbo].[ProjectProxy] ([ProjectID])
ON UPDATE CASCADE
GO

ALTER TABLE [dbo].[ReferenceProject] CHECK CONSTRAINT [FK_ReferenceProject_DiversityProjectProxy]
GO

ALTER TABLE [dbo].[ReferenceProject] ADD  CONSTRAINT [DF_ReferenceProject_LogCreatedWhen_1]  DEFAULT (getdate()) FOR [LogCreatedWhen]
GO

ALTER TABLE [dbo].[ReferenceProject] ADD  CONSTRAINT [DF_ReferenceProject_LogCreatedBy_1]  DEFAULT (user_name()) FOR [LogCreatedBy]
GO

ALTER TABLE [dbo].[ReferenceProject] ADD  CONSTRAINT [DF_ReferenceProject_LogUpdatedWhen_1]  DEFAULT (getdate()) FOR [LogUpdatedWhen]
GO

ALTER TABLE [dbo].[ReferenceProject] ADD  CONSTRAINT [DF_ReferenceProject_LogUpdatedBy_1]  DEFAULT (user_name()) FOR [LogUpdatedBy]
GO


--##################################################################################################
--  ProjectList       ##############################################################################
--##################################################################################################

CREATE VIEW [dbo].[ProjectList]
AS
SELECT     TOP 100 PERCENT dbo.ProjectProxy.Project, dbo.ProjectUser.ProjectID
FROM         dbo.ProjectUser INNER JOIN
                      dbo.ProjectProxy ON dbo.ProjectUser.ProjectID = dbo.ProjectProxy.ProjectID
WHERE     (dbo.ProjectUser.LoginName = USER_NAME())
GROUP BY dbo.ProjectProxy.Project, dbo.ProjectUser.ProjectID
ORDER BY dbo.ProjectProxy.Project

GO

GRANT SELECT ON [dbo].[ProjectList] TO [DiversityReferencesUser]
GO

